@@ -202,7 +202,7 @@ class CameraInput(TypedDict):
     urls: StreamUrls
 
 
-CameraRoles = Literal["high-resolution", "mid-resolution", "low-resolution", "snapshot", "none"]
+CameraRoles = Literal["high-resolution", "mid-resolution", "low-resolution", "snapshot"]
 
 CameraExtensionWithoutHub = Literal[
     "prebuffer",
@@ -620,8 +620,7 @@ class StreamInfo(TypedDict):
 
 
 class BasePrebufferState(TypedDict):
-    maxDuration: int
-    availableDuration: int
+    duration: int
 
 
 class PrebufferStateTrue(BasePrebufferState):
@@ -647,9 +646,6 @@ class CameraDelegate(metaclass=ABCMeta):
     @abstractmethod
     async def snapshot(self) -> bytes: ...
 
-    @abstractmethod
-    async def reboot(self) -> None: ...
-
 
 CameraDelegateMethodNames = Literal["reboot", "snapshot"]
 
@@ -734,9 +730,7 @@ class ImageMetadata(TypedDict):
 
 
 class AudioMetadata(TypedDict):
-    sampleRate: int
-    channels: int
-    format: str
+    mimeType: Literal["audio/mpeg", "audio/wav", "audio/ogg"]
 
 
 class FrameMetadata(TypedDict):
@@ -839,8 +833,7 @@ class CameraDevice(Protocol):
     mid_resolution_source: Optional[CameraSource]
     low_resolution_source: Optional[CameraSource]
 
-    cameraDelegate: CameraDelegate
-    ptzDelegate: CameraPTZDelegate
+    ptz: CameraPTZDelegate
 
     @overload
     def set_delegate(self, name: Literal["cameraDelegate"], delegate: CameraDelegate) -> None: ...
